"""Telegram Gateway verification client library."""

from .client import TelegramGatewayClient
from .exceptions import (
    TelegramGatewayAPIError,
    TelegramGatewayError,
    TelegramGatewayHTTPError,
    TelegramGatewayValidationError,
)
from .models import DeliveryStatus, RequestStatus, VerificationStatus
from .webhook import compute_signature, verify_callback_signature

__all__ = [
    "TelegramGatewayClient",
    "TelegramGatewayError",
    "TelegramGatewayHTTPError",
    "TelegramGatewayAPIError",
    "TelegramGatewayValidationError",
    "RequestStatus",
    "DeliveryStatus",
    "VerificationStatus",
    "compute_signature",
    "verify_callback_signature",
]
